Skip to contents

Intermediate-scale gridded (800m) soil property and interpretation maps from aggregated SSURGO and STATSGO data. These maps were developed by USDA-NRCS-SPSD staff in collaboration with UCD-LAWR. Originally for educational use and interactive thematic maps, these data are a suitable alternative to gridded STATSGO-derived thematic soil maps. The full size grids can be downloaded here.

Usage

ISSR800.wcs(aoi, var, res = 800, quiet = FALSE)

Arguments

aoi

area of interest (AOI) defined using a terra pakcage objects (SpatRaster, SpatVector, ext), sf objects (sf, sfc), raster package object (RasterLayer, bbox), sp package Spatial*, or a list, see details

var

ISSR-800 grid name (case insensitive), see details

res

grid resolution, units of meters. The native resolution of ISSR800 grids (this WCS) is 800m.

quiet

logical, passed to curl::curl_download to enable / suppress URL and progress bar for download.

Value

SpatRaster (or RasterLayer) object, or try-error if the WCS request fails.

Details

When specified as a list, aoi should contain:

  • aoi: bounding-box specified as (xmin, ymin, xmax, ymax) e.g. c(-114.16, 47.65, -114.08, 47.68)

  • crs: coordinate reference system of BBOX, e.g. 'OGC:CRS84' (EPSG:4326, WGS84 Longitude/Latitude)

The WCS query is parameterized using a rectangular extent derived from the above AOI specification, after conversion to the native CRS (EPSG:5070) of the ISSR800 grids.

Variables available from this WCS can be queried using WCS_details(wcs = 'ISSR800').

varcrsdescription
caco3_kg_sq_mEPSG:5070Total CaCO3 (kg/m^2)
cec_025cmEPSG:5070CEC at pH 7 0-25cm depth (cmol+/kg)
cec_050cmEPSG:5070CEC at pH 7 0-50cm depth (cmol+/kg)
cec_05cmEPSG:5070CEC at pH 7 0-5cm depth (cmol+/kg)
clay_025cmEPSG:5070clay percent 0-25cm depth
clay_05cmEPSG:5070clay percent 0-5cm depth
clay_2550cmEPSG:5070clay percent 25-50cm depth
clay_3060cmEPSG:5070clay percent 30-60cm depth
drainage_classEPSG:5070Soil Drainage Class
ec_025cmEPSG:5070EC 0-25cm depth (dS/m)
ec_05cmEPSG:5070EC 0-5cm depth (dS/m)
greatgroupEPSG:5070Soil Taxonomy: Greatgroup
hydgrpEPSG:5070Hydrologic Soil Group
lcc_irrigatedEPSG:5070Land Capability Class, irrigated
lcc_nonirrigatedEPSG:5070Land Capability Class, non-irrigated
n_componentsEPSG:5070Number of components per grid cell
n_polygonsEPSG:5070Number of polygons per grid cell
om_kg_sq_mEPSG:5070Total Soil Organic Matter (kg/m^2)
pawsEPSG:5070total plant available water storage (cm water)
paws_025cmEPSG:5070plant available water storage 0-25cm depth (cm water)
paws_050cmEPSG:5070plant available water storage 0-50cm depth (cm water)
ph_025cmEPSG:5070pH 1:1 H2O 0-25cm depth
ph_05cmEPSG:5070pH 1:1 H2O 0-5cm depth
ph_2550cmEPSG:5070pH 1:1 H2O 25-50cm depth
ph_3060cmEPSG:5070pH 1:1 H2O 30-60cm depth
sand_025cmEPSG:5070sand percent 0-25cm depth
sand_05cmEPSG:5070sand percent 0-5cm depth
sand_2550cmEPSG:5070sand percent 25-50cm depth
sand_3060cmEPSG:5070sand percent 30-60cm depth
sarEPSG:5070SAR, entire profile
series_nameEPSG:5070Soil Series Name
silt_025cmEPSG:5070silt percent 0-25cm depth
silt_05cmEPSG:5070silt percent 0-5cm depth
silt_2550cmEPSG:5070silt percent 25-50cm depth
silt_3060cmEPSG:5070silt percent 30-60cm depth
soilorderEPSG:5070Soil Taxonomy: Soil Order
ssurgo_pctEPSG:5070SSURGO data available, fraction of 800x800m grid cell
statsgo_pctEPSG:5070STATSGO data available, fraction of 800x800m grid cell
strEPSG:5070Soil Temperature Regime
suborderEPSG:5070Soil Taxonomy: Suborder
survey_typeEPSG:5070Soil survey data source
texture_025cmEPSG:5070Soil Texture Class, 0-25cm
texture_05cmEPSG:5070Soil Texture Class, 0-5cm
texture_2550cmEPSG:5070Soil Texture Class, 25-50cm
wegEPSG:5070Wind Erodibility Group
weiEPSG:5070Wind Erodibility Index

Note

There are still some issues to be resolved related to the encoding of NA Variables with a natural zero (e.g. SAR) have 0 set to NA.

Author

D.E. Beaudette and A.G. Brown

Examples


if (FALSE) { # \dontrun{
library(terra)

# see WCS_details() for variable options
WCS_details(wcs = 'ISSR800')

# get wind erodibility group
res <- ISSR800.wcs(list(aoi = c(-116, 35, -115.5, 35.5), crs = "EPSG:4326"), 
                   var = 'weg', res = 800)
plot(res)
} # }