SCAN and SNOTEL station metadata, a work in progress.
data("SCAN_SNOTEL_metadata")A data frame with 1092 observations on the following 12 variables.
Namestation name
Sitestation ID
Statestate
Networksensor network: SCAN / SNOTEL
Countycounty
Elevation_ftstation elevation in feet
Latitudelatitude of station
Longitudelongitude of station
HUCassociated watershed
climstanmclimate station name (TODO: remove this column)
upedonidassociated user pedon ID
pedlabsampnumassociated lab sample ID
These data have been compiled from several sources and represent a progressive effort to organize SCAN/SNOTEL station metadata. Therefore, some records may be missing or incorrect. Details on this effort can be found at the associated GH issue page: https://github.com/ncss-tech/soilDB/issues/61.