View source: R/get_component_data_from_NASIS_db.R
| get_comonth_from_NASIS_db | R Documentation |
Get component month data from a local NASIS Database.
get_comonth_from_NASIS_db(SS = TRUE, fill = FALSE, dsn = NULL)
SS |
get data from the currently loaded Selected Set in NASIS or from the entire local database (default: TRUE) |
fill |
should missing "month" rows in the comonth table be filled with NA (FALSE) |
dsn |
Optional: path or DBIConnection to
local database containing NASIS table
structure; default: |
A list with the results.
Stephen Roecker
fetchNASIS
if(local_NASIS_defined()) {
# query text note data
cm <- try(get_comonth_from_NASIS_db())
# show structure of component month data
str(cm)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.