Learn R Programming

soilDB (version 2.6.12)

get_mapunit_from_NASIS: Get Legend, Mapunit and Legend Mapunit Area Overlap Tables

Description

Get Legend, Mapunit and Legend Mapunit Area Overlap Tables

Usage

get_mapunit_from_NASIS(
  SS = TRUE,
  droplevels = TRUE,
  stringsAsFactors = default.stringsAsFactors(),
  dsn = NULL
)

get_legend_from_NASIS( SS = TRUE, droplevels = TRUE, stringsAsFactors = default.stringsAsFactors(), dsn = NULL )

get_lmuaoverlap_from_NASIS( SS = TRUE, droplevels = TRUE, stringsAsFactors = default.stringsAsFactors(), dsn = NULL )

get_projectmapunit_from_NASIS( SS = TRUE, stringsAsFactors = default.stringsAsFactors(), dsn = NULL )

Arguments

SS

fetch data from the currently loaded selected set in NASIS or from the entire local database (default: TRUE)

droplevels

Drop unused levels from farmlndcl and other factor levels from NASIS domains?

stringsAsFactors

logical: should character vectors be converted to factors? This argument is passed to the uncode() function. It does not convert those vectors that have been set outside of uncode() (i.e. hard coded).

dsn

Optional: path to local SQLite database containing NASIS table structure; default: NULL