Intermediate-scale gridded (800m) soil property and interpretation maps from aggregated SSURGO and STATSGO data. These maps were developed by USDA-NRCS-SPSD staff in collaboration with UCD-LAWR. Originally for educational use and interactive thematic maps, these data are a suitable alternative to gridded STATSGO-derived thematic soil maps. The full size grids can be downloaded here.
ISSR800.wcs(aoi, var, res = 800, quiet = FALSE)area of interest (AOI) defined using a Spatial*, RasterLayer, sf, sfc or bbox object or a list, see details
ISSR-800 grid name, see details
grid resolution, units of meters. The native resolution of ISSR-800 grids (this WCS) is 800m.
logical, passed to download.file to enable / suppress URL and progress bar for download.
#' @details aoi should be specified as a Spatial*, RasterLayer, sf, sfc, or bbox object or a list containing:
aoibounding-box specified as (xmin, ymin, xmax, ymax) e.g. c(-114.16, 47.65, -114.08, 47.68)
crscoordinate reference system of BBOX, e.g. '+init=epsg:4326'
The WCS query is parameterized using raster::extent derived from the above AOI specification, after conversion to the native CRS (EPSG:5070) of the ISSR-800 grids.
Variables available from this WCS can be queried using WCS_details(wcs = 'ISSR800').
raster object containing indexed map unit keys and associated raster attribute table or a try-error if request fails