fetchNASISLabData: Fetch lab data used site/horizon data from a PedonPC database.
Description
Fetch KSSL laboratory pedon/horizon layer data from a local NASIS database, return as a SoilProfileCollection object.
Usage
fetchNASISLabData(SS = TRUE)
Arguments
SS
fetch data from the currently loaded selected set in NASIS or from the entire local database (default: TRUE)
Value
a SoilProfileCollection class object
Details
This function currently works only on Windows, and requires a 'nasis_local' ODBC connection.