Get site-level data from a local NASIS database.
get_site_data_from_NASIS_db(
SS = TRUE,
nullFragsAreZero = TRUE,
stringsAsFactors = default.stringsAsFactors(),
dsn = NULL
)fetch data from Selected Set in NASIS or from the entire local
database (default: TRUE)
should surface fragment cover percentages of NULL be interpreted as 0? (default: TRUE)
logical: should character vectors be converted to
factors? This argument is passed to the uncode() function. It does not
convert those vectors that have been set outside of uncode() (i.e. hard
coded).
Optional: path to local SQLite database containing NASIS
table structure; default: NULL
A data.frame
When multiple "site bedrock" entries are present, only the shallowest is returned by this function.