Learn R Programming

soilDB (version 2.5.9)

get_site_data_from_NASIS_db: Extract Site Data from a local NASIS Database

Description

Get site-level data from a local NASIS database.

Usage

get_site_data_from_NASIS_db(SS = TRUE, stringsAsFactors = default.stringsAsFactors())

Arguments

SS

fetch data from Selected Set in NASIS or from the entire local database (default: TRUE)

stringsAsFactors

logical: should character vectors be converted to factors? This argument is passed to the uncode() function. It does not convert those vectors that have been set outside of uncode() (i.e. hard coded). The 'factory-fresh' default is TRUE, but this can be changed by setting options(stringsAsFactors = FALSE)

Value

A data.frame.

Details

When multiple "site bedrock" entries are present, only the shallowest is returned by this function.

See Also

get_hz_data_from_NASIS_db,