get_veg_from_NPS_PLOTS_db: Get Vegetation Data from an NPS PLOTS Database
Description
Used to extract species, stratum, and cover vegetation data from a backend
NPS PLOTS Database. Currently works for any Microsoft Access database with
an .mdb file format.
Usage
get_veg_from_NPS_PLOTS_db(dsn)
Value
A data.frame with vegetation data in a long format with linkage to
NRCS soil pedon data via the site_id key field.
Arguments
- dsn
file path to the NPS PLOTS access database on your system.